==> corsix-th_0.62.orig.tar.gz: CorsixTH-0.62/README.md <==
![](http://i.imgur.com/fYp148T.jpg)
### Latest Release [![Release 0.60](https://img.shields.io/badge/release-0.60-brightgreen.svg)](https://github.com/CorsixTH/CorsixTH/releases) [![Travis Build Status](https://travis-ci.org/CorsixTH/CorsixTH.svg?branch=master)](https://travis-ci.org/CorsixTH/CorsixTH) [![AppVeyor Build Status](https://ci.appveyor.com/api/projects/status/github/CorsixTH/CorsixTH?branch=master&svg=true)](https://ci.appveyor.com/project/TheCycoONE/corsixth)

##### [Forum](http://forums.corsixth.com) | [IRC Chat](http://webchat.freenode.net/?channels=corsix-th) | [Report Issue](https://github.com/CorsixTH/CorsixTH/issues/new)

A reimplementation of the 1997 Bullfrog business sim Theme Hospital. As well as faithfully recreating the original, CorsixTH adds support for modern operating systems (Windows, Mac OSX and Linux), high resolutions and much more.

![](http://i.imgur.com/qHV60Ui.png)


## Getting Started ##

You will need the following:

- Grab the latest release for your system [here](https://github.com/CorsixTH/CorsixTH/releases).
- We use graphics, sound and other data from the original game so one of the following is required:
   - Original game CD from eBay etc. or your dusty bookshelf:smile:
   - A download from [GOG.com](http://www.gog.com/game/theme_hospital) or [Origin](https://www.origin.com/en-gb/store/buy/theme-hospital-origin/pc-download/base-game/standard-edition)

 Head over to our [getting started](https://github.com/CorsixTH/CorsixTH/wiki/Getting-Started) page for more detail.
 
## Developers
### Coders and non-coders we want you!

We are always looking for help with improving CorsixTH. The code base is made up of Lua and C++ (with a little C added in for fun) however most of the game logic is written in Lua, we love Lua and its approachable and easy to pick up nature, so hit fork and get started! But don't worry if you don't code as we can always use your help in other areas and if you have ideas for the project please contact us or open a new issue!


###### Features & Bugfixes ######
We still have features to add and bugs to fix, check out our [TODO](https://github.com/CorsixTH/CorsixTH/wiki/Programming-Ideas) list and the bug tracker [here](https://github.com/CorsixTH/CorsixTH/issues). Want to talk about adding a feature? post on our Google group or [contact us](#Contact).

###### Translation ######
CorsixTH has translations for 18 languages, some need updates. Head over to our [dedicated forum section](http://forums.corsixth.com/index.php/board,11.0.html) for more information.

###### Other ######

Not a programmer? Don't know another language? Well you can still help! come visit our [forum](http://forums.corsixth.com/) and get involved in map creation, graphics replacements and much more.

## More

Our [wiki](https://github.com/CorsixTH/CorsixTH/wiki) is a good place to start, if you can't find what you are looking for feel free to contact us using one of the methods below.

## Contact

- CorsixTH forums located [here](http://forums.corsixth.com/)
- Follow us on twitter ([**@CorsixTH**](https://twitter.com/CorsixTH)) and on [Facebook](https://facebook.com/CorsixTH)
- IRC #Corsix-TH on irc.freenode.net
- Subscribe to our [Google Developer group](http://groups.google.com/group/corsix-th-dev)

==> corsix-th_0.63.orig.tar.gz: CorsixTH-0.63/README.md <==
![](http://i.imgur.com/fYp148T.jpg)
### Latest Release [![Release](https://img.shields.io/github/release/CorsixTH/CorsixTH.svg?colorB=green)](https://github.com/CorsixTH/CorsixTH/releases) [![Travis Build Status](https://travis-ci.org/CorsixTH/CorsixTH.svg?branch=master)](https://travis-ci.org/CorsixTH/CorsixTH) [![AppVeyor Build Status](https://ci.appveyor.com/api/projects/status/github/CorsixTH/CorsixTH?branch=master&svg=true)](https://ci.appveyor.com/project/TheCycoONE/corsixth)

##### [Forum](http://forums.corsixth.com) | [IRC Chat](http://webchat.freenode.net/?channels=corsix-th) | [Report Issue](https://github.com/CorsixTH/CorsixTH/issues/new)

A reimplementation of the 1997 Bullfrog business sim Theme Hospital. As well as faithfully recreating the original, CorsixTH adds support for modern operating systems (Windows, macOS, Linux and BSD), high resolutions and much more.

![](http://i.imgur.com/qHV60Ui.png)


## Getting Started ##

You will need the following:

- Grab the latest installer for your system:
   - Windows and macOS builds can be downloaded directly from [releases](https://github.com/CorsixTH/CorsixTH/releases).
   - Linux and BSD repositories use either corsixth or corsix-th names [packaged versions](https://repology.org/metapackage/corsixth).
- We use graphics, sound and other data from the original game so one of the following is required:
   - Original game CD from eBay etc. or your dusty bookshelf:smile:
   - A download from [GOG.com](http://www.gog.com/game/theme_hospital) or [Origin](https://www.origin.com/en-gb/store/buy/theme-hospital-origin/pc-download/base-game/standard-edition)

 Head over to our [getting started](https://github.com/CorsixTH/CorsixTH/wiki/Getting-Started) page for more detail.
 
## Developers
### Coders and non-coders we want you!

We are always looking for help with improving CorsixTH. The code base is made up of Lua and C++ (with a little C added in for fun) however most of the game logic is written in Lua, we love Lua and its approachable and easy to pick up nature, so hit fork and get started! But don't worry if you don't code as we can always use your help in other areas and if you have ideas for the project please contact us or open a new issue!


###### Features & Bugfixes ######
We still have features to add and bugs to fix, check out our [TODO](https://github.com/CorsixTH/CorsixTH/wiki/Programming-Ideas) list and the bug tracker [here](https://github.com/CorsixTH/CorsixTH/issues). Want to talk about adding a feature? post on our Google group or [contact us](#Contact).

###### Translation ######
CorsixTH has translations for 18 languages, some need updates. Head over to our [dedicated forum section](http://forums.corsixth.com/index.php/board,11.0.html) for more information.

###### Other ######

Not a programmer? Don't know another language? Well you can still help! come visit our [forum](http://forums.corsixth.com/) and get involved in map creation, graphics replacements and much more.

## More

Our [wiki](https://github.com/CorsixTH/CorsixTH/wiki) is a good place to start, if you can't find what you are looking for feel free to contact us using one of the methods below.

## Contact

- CorsixTH forums located [here](http://forums.corsixth.com/)
- Follow us on twitter ([**@CorsixTH**](https://twitter.com/CorsixTH)) and on [Facebook](https://facebook.com/CorsixTH)
- IRC #Corsix-TH on irc.freenode.net
- Subscribe to our [Google Developer group](http://groups.google.com/group/corsix-th-dev)
